==> zeptomail-1.0.0.tar.gz: zeptomail/src/Form/ZeptoMailSettingsForm.php <==
<?php

namespace Drupal\ZeptoMail\Form;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\ZeptoMail\ZeptoMailHandler;
use Symfony\Component\DependencyInjection\ContainerInterface;


class ZeptoMailSettingsForm extends ConfigFormBase {

  protected $postmarkHandler;


  public function __construct(ConfigFactoryInterface $config_factory, ZeptoMailHandler $postmark_handler) {
    parent::__construct($config_factory);

    $this->postmarkHandler = $postmark_handler;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('config.factory'),
      $container->get('zeptomail.mail_handler')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'zeptomail_settings_form';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['zeptomail.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    // The user's ZeptoMail API key
    $form['domain'] = [
      '#type' => 'select',
      '#title' => $this->t('Select Domain'),
      '#options' => [
          'zoho.com' => 'zeptomail.zoho.com',
          'zoho.eu' => 'zeptomail.zoho.eu',
          'zoho.in' => 'zeptomail.zoho.in',
          'zoho.jp' => 'zeptomail.zoho.jp',
          'zoho.sa' => 'zeptomail.zoho.sa',
          'zoho.com.au' => 'zeptomail.zoho.com.au',
          'zoho.com.cn' => 'zeptomail.zoho.com.cn',
          'zohocloud.ca' => 'zohocloud.ca'
      ],
  ];
  $apikey = $this->config('zeptomail.settings')->get('api_key');
    $form['api_key'] = [
      '#type' => 'password',
      '#title' => $this->t('Zeptomail API Token'),
      '#default_value' => $this->config('zeptomail.settings')->get('api_key'),
      '#description' => $this->t('ZeptoMail API token'),
      '#required' => TRUE,
    ];
    $form['from_address'] = [
      '#type' => 'textfield',
      '#title' => $this->t('From address'),
      '#default_value' => $this->config('zeptomail.settings')->get('from_address'),
      '#description' => $this->t('The email address configured within ZeptoMail as the Sender Signature for the server associated with the Server API token.'),
      '#required' => TRUE,
    ];
    $form['from_name'] = [
      '#type' => 'textfield',
      '#title' => $this->t('From name'),
      '#default_value' => $this->config('zeptomail.settings')->get('from_name'),
      '#description' => $this->t('The email address configured within ZeptoMail as the Sender Signature for the server associated with the Server API token.'),
      '#required' => TRUE,
    ];
    
    $form['test'] = [
      '#type' => 'details',
      '#title' => $this->t('Test email'),
      '#open' => FALSE,
    ];
    $form['test']['test_address'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Recipient'),
      '#default_value' => '',
      '#description' => $this->t('Enter a valid email address to send a test email.'),
    ];
  
    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    parent::validateForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $config = $this->config('zeptomail.settings');
    $config
      ->set('domain', $form_state->getValue('domain'))
      ->set('api_key', $form_state->getValue('api_key'))
      ->set('from_address', $form_state->getValue('from_address'))
      ->set('from_name', $form_state->getValue('from_name'))
      ->save();

    

    parent::submitForm($form, $form_state);
  }

}

==> zeptomail-1.0.3.tar.gz: zeptomail/src/Form/ZeptoMailSettingsForm.php <==
<?php

namespace Drupal\ZeptoMail\Form;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;


class ZeptoMailSettingsForm extends ConfigFormBase {



  public function __construct(ConfigFactoryInterface $config_factory) {
    parent::__construct($config_factory);

  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('config.factory')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'zeptomail_settings_form';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['zeptomail.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    // The user's ZeptoMail API key
    $form['domain'] = [
      '#type' => 'select',
      '#title' => $this->t('Select Domain'),
      '#options' => [
          'zoho.com' => 'zeptomail.zoho.com',
          'zoho.eu' => 'zeptomail.zoho.eu',
          'zoho.in' => 'zeptomail.zoho.in',
          'zoho.jp' => 'zeptomail.zoho.jp',
          'zoho.sa' => 'zeptomail.zoho.sa',
          'zoho.com.au' => 'zeptomail.zoho.com.au',
          'zoho.com.cn' => 'zeptomail.zoho.com.cn',
          'zohocloud.ca' => 'zohocloud.ca'
      ],
  ];
  $apikey = $this->config('zeptomail.settings')->get('api_key');
    $form['api_key'] = [
      '#type' => 'password',
      '#title' => $this->t('Zeptomail API Token'),
      '#default_value' => $this->config('zeptomail.settings')->get('api_key'),
      '#description' => $this->t('ZeptoMail API token'),
      '#required' => TRUE,
    ];
    $form['from_address'] = [
      '#type' => 'textfield',
      '#title' => $this->t('From address'),
      '#default_value' => $this->config('zeptomail.settings')->get('from_address'),
      '#description' => $this->t('The email address configured within ZeptoMail as the Sender Signature for the server associated with the Server API token.'),
      '#required' => TRUE,
    ];
    $form['from_name'] = [
      '#type' => 'textfield',
      '#title' => $this->t('From name'),
      '#default_value' => $this->config('zeptomail.settings')->get('from_name'),
      '#description' => $this->t('The email address configured within ZeptoMail as the Sender Signature for the server associated with the Server API token.'),
      '#required' => TRUE,
    ];
    
    $form['test'] = [
      '#type' => 'details',
      '#title' => $this->t('Test email'),
      '#open' => FALSE,
    ];
    $form['test']['test_address'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Recipient'),
      '#default_value' => '',
      '#description' => $this->t('Enter a valid email address to send a test email.'),
    ];
  
    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    parent::validateForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $config = $this->config('zeptomail.settings');
    $config
      ->set('domain', $form_state->getValue('domain'))
      ->set('api_key', $form_state->getValue('api_key'))
      ->set('from_address', $form_state->getValue('from_address'))
      ->set('from_name', $form_state->getValue('from_name'))
      ->save();

    

    parent::submitForm($form, $form_state);
  }

}
